==> haskell-css-text-0.1.3.0-308-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-Hwpqd850SbQHb0HVbb02hn
key:                  css-text-0.1.3.0-Hwpqd850SbQHb0HVbb02hn
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  993cc6870440f62a7ce1ffc2a1c63fb5
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-css-text
hs-libraries:         HScss-text-0.1.3.0-Hwpqd850SbQHb0HVbb02hn
depends:
    attoparsec-0.14.4-5WJushYcFmLGCbqKFNMNd6 base-4.17.2.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-css-text-0.1.3.0-309-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-4fKQKN7uFyoITmHs9kKTTT
key:                  css-text-0.1.3.0-4fKQKN7uFyoITmHs9kKTTT
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  2a6505e7d1cfe83180f58cf8c3cfe382
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-css-text
hs-libraries:         HScss-text-0.1.3.0-4fKQKN7uFyoITmHs9kKTTT
depends:
    attoparsec-0.14.4-HXvPhgAZIYuDm9YtcrLhPL base-4.17.2.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
